==> feathr-0.3.0.tar.gz: feathr-0.3.0/test/test_observation_setting.py <==
from feathr.settings import ObservationSettings


def test_observation_setting_with_timestamp():
    observation_settings = ObservationSettings(
        observation_path="abfss://feathrazuretest3fs@feathrazuretest3storage.dfs.core.windows.net/demo_data/green_tripdata_2020-04.csv",
        event_timestamp_column="lpep_dropoff_datetime",
        timestamp_format="yyyy-MM-dd HH:mm:ss")
    config = observation_settings.to_config()
    expected_config = """
            settings: {
                joinTimeSettings: {
                    timestampColumn: {
                        def: "lpep_dropoff_datetime"
                        format: "yyyy-MM-dd HH:mm:ss"
                    }
                }
            }
            
            observationPath: "abfss://feathrazuretest3fs@feathrazuretest3storage.dfs.core.windows.net/demo_data/green_tripdata_2020-04.csv"
        """
    assert ''.join(config.split()) == ''.join(expected_config.split())


def test_observation_setting_without_timestamp():
    observation_settings = ObservationSettings(
        observation_path='jdbc:snowflake://dqllago-ol19457.snowflakecomputing.com/?user=feathrintegration&sfWarehouse'
                         '=COMPUTE_WH&dbtable=CALL_CENTER&sfDatabase=SNOWFLAKE_SAMPLE_DATA&sfSchema=TPCDS_SF10TCL')
    config = observation_settings.to_config()
    expected_config = """            
            observationPath:"jdbc:snowflake://dqllago-ol19457.snowflakecomputing.com/?user=feathrintegration&sfWarehouse=COMPUTE_WH&dbtable=CALL_CENTER&sfDatabase=SNOWFLAKE_SAMPLE_DATA&sfSchema=TPCDS_SF10TCL"
        """
    assert ''.join(config.split()) == ''.join(expected_config.split())

==> feathr-0.5.0.tar.gz: feathr-0.5.0/test/test_observation_setting.py <==
from feathr.settings import ObservationSettings


def test_observation_setting_with_timestamp():
    observation_settings = ObservationSettings(
        observation_path="wasbs://public@azurefeathrstorage.blob.core.windows.net/sample_data/green_tripdata_2020-04.csv",
        event_timestamp_column="lpep_dropoff_datetime",
        timestamp_format="yyyy-MM-dd HH:mm:ss")
    config = observation_settings.to_feature_config()
    expected_config = """
            settings: {
                joinTimeSettings: {
                    timestampColumn: {
                        def: "lpep_dropoff_datetime"
                        format: "yyyy-MM-dd HH:mm:ss"
                    }
                }
            }
            
            observationPath: "wasbs://public@azurefeathrstorage.blob.core.windows.net/sample_data/green_tripdata_2020-04.csv"
        """
    assert ''.join(config.split()) == ''.join(expected_config.split())


def test_observation_setting_without_timestamp():
    observation_settings = ObservationSettings(
        observation_path='jdbc:snowflake://dqllago-ol19457.snowflakecomputing.com/?user=feathrintegration&sfWarehouse'
                         '=COMPUTE_WH&dbtable=CALL_CENTER&sfDatabase=SNOWFLAKE_SAMPLE_DATA&sfSchema=TPCDS_SF10TCL')
    config = observation_settings.to_feature_config()
    expected_config = """            
            observationPath:"jdbc:snowflake://dqllago-ol19457.snowflakecomputing.com/?user=feathrintegration&sfWarehouse=COMPUTE_WH&dbtable=CALL_CENTER&sfDatabase=SNOWFLAKE_SAMPLE_DATA&sfSchema=TPCDS_SF10TCL"
        """
    assert ''.join(config.split()) == ''.join(expected_config.split())
